==> lighterend-1.0.0-0-1.21.9-sources.jar: io/github/openbagtwo/lighterend/mobs/ChorusCrab.java <==
package io.github.openbagtwo.lighterend.mobs;

import io.github.openbagtwo.lighterend.registries.LighterEndMobs;
import io.github.openbagtwo.lighterend.registries.LighterEndSounds;
import io.github.openbagtwo.lighterend.registries.LighterEndTags;
import net.minecraft.class_1266;
import net.minecraft.class_1282;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1296;
import net.minecraft.class_1299;
import net.minecraft.class_1304;
import net.minecraft.class_1315;
import net.minecraft.class_1338;
import net.minecraft.class_1341;
import net.minecraft.class_1347;
import net.minecraft.class_1361;
import net.minecraft.class_1366;
import net.minecraft.class_1376;
import net.minecraft.class_1391;
import net.minecraft.class_1394;
import net.minecraft.class_1399;
import net.minecraft.class_1408;
import net.minecraft.class_1410;
import net.minecraft.class_1429;
import net.minecraft.class_1560;
import net.minecraft.class_1588;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1856;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_2940;
import net.minecraft.class_2943;
import net.minecraft.class_2945;
import net.minecraft.class_3218;
import net.minecraft.class_3414;
import net.minecraft.class_3481;
import net.minecraft.class_3483;
import net.minecraft.class_3489;
import net.minecraft.class_3730;
import net.minecraft.class_4538;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_5425;
import net.minecraft.class_5819;
import org.jetbrains.annotations.Nullable;

public class ChorusCrab extends class_1429 {

  private static final class_2940<Byte> CLIMBING = class_2945.method_12791(
      ChorusCrab.class,
      class_2943.field_13319
  );

  public ChorusCrab(class_1299<? extends ChorusCrab> entityType, class_1937 world) {
    super(entityType, world);
  }

  public static class_5132.class_5133 createCrabAttributes() {
    return class_1588.method_26918()
        .method_26868(class_5134.field_23716, 32.0)
        .method_26868(class_5134.field_23719, 0.1)
        .method_26868(class_5134.field_23728, 0)
        .method_26868(class_5134.field_47761, 2.0)
        .method_26868(class_5134.field_52450, 8.0)
        .method_26868(class_5134.field_23721, 2.0)
        .method_26868(class_5134.field_23722, 3.0)
        .method_26868(class_5134.field_23723, 0.1)
        .method_26868(class_5134.field_23724, 8.0)
        .method_26868(class_5134.field_47759, 1.5)
        .method_26868(class_5134.field_47758, 1.5)
        .method_26868(class_5134.field_23718, 5.0);
  }

  @Override
  protected void method_5959() {
    this.field_6201.method_6277(1, new class_1347(this));
    this.field_6201.method_6277(1, new class_1399(this));
    this.field_6201.method_6277(2, new class_1366(this, 0.5, false));
    this.field_6201.method_6277(3, new MateGoal(this));
    this.field_6201.method_6277(
        4,
        new class_1391(this, 0.8F, class_1856.method_8091(class_1802.field_8710), true)
    );
    this.field_6201.method_6277(
        5,
        new class_1338(this, class_1657.class, 3.0F, 0.25F, 1F, (entity) -> true)
    );
    this.field_6201.method_6277(8, new class_1394(this, 0.8));
    this.field_6201.method_6277(10, new class_1361(this, class_1657.class, 8.0F));
    this.field_6201.method_6277(10, new class_1376(this));
  }

  @Override
  public class_3414 method_5994() {
    return LighterEndSounds.CRAB_IDLE;
  }

  @Override
  protected class_3414 method_6011(class_1282 source) {
    return LighterEndSounds.CRAB_HURT;
  }

  @Override
  protected class_3414 method_6002() {
    return LighterEndSounds.CRAB_DEATH;
  }

  @Override
  protected void method_5712(class_2338 pos, class_2680 state) {
    this.method_5783(LighterEndSounds.CRAB_STEP, 0.15F, 1.0F);
  }

  @Override
  public boolean method_6049(class_1293 effect) {
    if (effect.method_55654(class_1294.field_5899)) {
      return !this.method_5864().method_20210(class_3483.field_48290);
    }
    return super.method_6049(effect);
  }

  @Nullable
  @Override
  public class_1315 method_5943(
      class_5425 world,
      class_1266 difficulty,
      class_3730 spawnReason,
      @Nullable class_1315 entityData
  ) {
    entityData = super.method_5943(world, difficulty, spawnReason, entityData);

    if (world.method_8409().method_43048(512) == 0 && (spawnReason != class_3730.field_16466)) {
      class_1560 rider = class_1299.field_6091.method_5883(this.method_73183(), class_3730.field_16460);
      if (rider != null) {
        rider.method_5808(this.method_23317(), this.method_23318(), this.method_23321(), this.method_36454(), 0.0F);
        rider.method_5943(world, difficulty, spawnReason, null);
        rider.method_5804(this);
      }
    }
    this.method_5952(true);
    this.method_5964(world.method_8409(), difficulty);
    this.method_30759(world, world.method_8409(), difficulty);

    return entityData;
  }

  @Override
  protected void method_5964(class_5819 random, class_1266 localDifficulty) {
    if (random.method_43048(512) == 0) {
      this.method_5673(class_1304.field_6173, new class_1799(class_1802.field_8802));
      this.method_25939(class_1304.field_6173);

    }
  }

  @Override
  public boolean method_5939(class_1799 stack) {
    return stack.method_31573(class_3489.field_42611);
  }

  @Override
  public @Nullable class_1296 method_5613(class_3218 world, class_1296 entity) {
    return LighterEndMobs.CHORUS_CRAB.mob.method_5883(world, class_3730.field_16466);
  }

  @Override
  public float method_6144(class_2338 pos, class_4538 world) {
    return world.method_8320(pos.method_10074()).method_26164(class_3481.field_15466) ? 12.0F
        : world.method_8320(pos.method_10074()).method_26164(LighterEndTags.END_SOIL) ? 10.0F
            : world.method_42309(pos);
  }

  @Override
  public boolean method_6481(class_1799 stack) {
    return stack.method_31574(class_1802.field_8710);
  }

  @Override
  protected class_1408 method_5965(class_1937 world) {
    return new class_1410(this, world);
  }

  @Override
  protected void method_5693(class_2945.class_9222 builder) {
    super.method_5693(builder);
    builder.method_56912(CLIMBING, (byte) 0);
  }

  @Override
  public void method_5773() {
    super.method_5773();
    if (!this.method_73183().method_8608()) {
      this.setClimbingWall(this.field_5976);
    }
    if (this.method_5618() >= 0 && this.method_5765()) {
      this.method_29239();
    }
  }

  @Override
  public boolean method_6474(class_1429 other) {
    if (this.method_5782() || other.method_5782()) {
      return false;
    }
    return super.method_6474(other);
  }

  @Override
  public void method_49794(class_3218 world, class_1429 other, @Nullable class_1296 baby) {
    super.method_49794(world, other, baby);
    if (baby != null) {
      baby.method_5873(this, true, true);
    }
  }

  public void setClimbingWall(boolean climbing) {
    byte b = this.field_6011.method_12789(CLIMBING);
    if (climbing) {
      b = (byte) (b | 1);
    } else {
      b = (byte) (b & -2);
    }

    this.field_6011.method_12778(CLIMBING, b);
  }

  class MateGoal extends class_1341 {

    public MateGoal(class_1429 crab) {
      super(crab, 1.0F);
    }

    @Override
    public boolean method_6264() {
      if (this.field_6404.method_5782()) {
        return false;
      }
      return super.method_6264();
    }

    @Override
    public boolean method_6266() {
      if (!this.field_6406.method_5782()) {
        return false;
      }
      return super.method_6266();
    }

    @Override
    public void method_6268() {
      super.method_6268();
      if (this.field_6404.method_5858(this.field_6406) < 9.0) {  // kludge to fix failure to breed
        this.method_6249();
      }
    }
  }
}

==> lighterend-1.0.1-0-1.21.9-sources.jar: io/github/openbagtwo/lighterend/mobs/ChorusCrab.java <==
package io.github.openbagtwo.lighterend.mobs;

import io.github.openbagtwo.lighterend.registries.LighterEndMobs;
import io.github.openbagtwo.lighterend.registries.LighterEndSounds;
import io.github.openbagtwo.lighterend.registries.LighterEndTags;
import net.minecraft.class_1266;
import net.minecraft.class_1282;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1296;
import net.minecraft.class_1299;
import net.minecraft.class_1304;
import net.minecraft.class_1315;
import net.minecraft.class_1338;
import net.minecraft.class_1341;
import net.minecraft.class_1347;
import net.minecraft.class_1361;
import net.minecraft.class_1366;
import net.minecraft.class_1376;
import net.minecraft.class_1391;
import net.minecraft.class_1394;
import net.minecraft.class_1399;
import net.minecraft.class_1408;
import net.minecraft.class_1410;
import net.minecraft.class_1429;
import net.minecraft.class_1560;
import net.minecraft.class_1588;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1856;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_2940;
import net.minecraft.class_2943;
import net.minecraft.class_2945;
import net.minecraft.class_3218;
import net.minecraft.class_3414;
import net.minecraft.class_3481;
import net.minecraft.class_3483;
import net.minecraft.class_3489;
import net.minecraft.class_3730;
import net.minecraft.class_4538;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_5425;
import net.minecraft.class_5819;
import org.jetbrains.annotations.Nullable;

public class ChorusCrab extends class_1429 {

  private static final class_2940<Byte> CLIMBING = class_2945.method_12791(
      ChorusCrab.class,
      class_2943.field_13319
  );

  public ChorusCrab(class_1299<? extends ChorusCrab> entityType, class_1937 world) {
    super(entityType, world);
  }

  public static class_5132.class_5133 createCrabAttributes() {
    return class_1588.method_26918()
        .method_26868(class_5134.field_23716, 32.0)
        .method_26868(class_5134.field_23719, 0.1)
        .method_26868(class_5134.field_23728, 0)
        .method_26868(class_5134.field_47761, 2.0)
        .method_26868(class_5134.field_52450, 8.0)
        .method_26868(class_5134.field_23721, 2.0)
        .method_26868(class_5134.field_23722, 3.0)
        .method_26868(class_5134.field_23723, 0.1)
        .method_26868(class_5134.field_23724, 8.0)
        .method_26868(class_5134.field_47759, 1.5)
        .method_26868(class_5134.field_47758, 1.5)
        .method_26868(class_5134.field_23718, 5.0);
  }

  @Override
  protected void method_5959() {
    this.field_6201.method_6277(1, new class_1347(this));
    this.field_6201.method_6277(1, new class_1399(this));
    this.field_6201.method_6277(2, new class_1366(this, 0.5, false));
    this.field_6201.method_6277(3, new MateGoal(this));
    this.field_6201.method_6277(
        4,
        new class_1391(this, 0.8F, class_1856.method_8091(class_1802.field_8710), true)
    );
    this.field_6201.method_6277(
        5,
        new class_1338(this, class_1657.class, 3.0F, 0.25F, 1F, (entity) -> true)
    );
    this.field_6201.method_6277(8, new class_1394(this, 0.8));
    this.field_6201.method_6277(10, new class_1361(this, class_1657.class, 8.0F));
    this.field_6201.method_6277(10, new class_1376(this));
  }

  @Override
  public class_3414 method_5994() {
    return LighterEndSounds.CRAB_IDLE;
  }

  @Override
  protected class_3414 method_6011(class_1282 source) {
    return LighterEndSounds.CRAB_HURT;
  }

  @Override
  protected class_3414 method_6002() {
    return LighterEndSounds.CRAB_DEATH;
  }

  @Override
  protected void method_5712(class_2338 pos, class_2680 state) {
    this.method_5783(LighterEndSounds.CRAB_STEP, 0.15F, 1.0F);
  }

  @Override
  public boolean method_6049(class_1293 effect) {
    if (effect.method_55654(class_1294.field_5899)) {
      return !this.method_5864().method_20210(class_3483.field_48290);
    }
    return super.method_6049(effect);
  }

  @Nullable
  @Override
  public class_1315 method_5943(
      class_5425 world,
      class_1266 difficulty,
      class_3730 spawnReason,
      @Nullable class_1315 entityData
  ) {
    entityData = super.method_5943(world, difficulty, spawnReason, entityData);
    if (spawnReason == class_3730.field_16466) {
      this.method_5971();
    } else if (world.method_8409().method_43048(512) == 0) {
      class_1560 rider = class_1299.field_6091.method_5883(this.method_73183(), class_3730.field_16460);
      if (rider != null) {
        rider.method_5808(this.method_23317(), this.method_23318(), this.method_23321(), this.method_36454(), 0.0F);
        rider.method_5943(world, difficulty, spawnReason, null);
        rider.method_5804(this);
      }
    }
    this.method_5952(true);
    this.method_5964(world.method_8409(), difficulty);
    this.method_30759(world, world.method_8409(), difficulty);

    return entityData;
  }

  @Override
  protected void method_5964(class_5819 random, class_1266 localDifficulty) {
    if (random.method_43048(512) == 0) {
      this.method_5673(class_1304.field_6173, new class_1799(class_1802.field_8802));
      this.method_25939(class_1304.field_6173);

    }
  }

  @Override
  public boolean method_5939(class_1799 stack) {
    return stack.method_31573(class_3489.field_42611);
  }

  @Override
  public @Nullable class_1296 method_5613(class_3218 world, class_1296 entity) {
    return LighterEndMobs.CHORUS_CRAB.mob.method_5883(world, class_3730.field_16466);
  }

  @Override
  public float method_6144(class_2338 pos, class_4538 world) {
    return world.method_8320(pos.method_10074()).method_26164(class_3481.field_15466) ? 12.0F
        : world.method_8320(pos.method_10074()).method_26164(LighterEndTags.END_SOIL) ? 10.0F
            : world.method_42309(pos);
  }

  @Override
  public boolean method_6481(class_1799 stack) {
    return stack.method_31574(class_1802.field_8710);
  }

  @Override
  protected class_1408 method_5965(class_1937 world) {
    return new class_1410(this, world);
  }

  @Override
  protected void method_5693(class_2945.class_9222 builder) {
    super.method_5693(builder);
    builder.method_56912(CLIMBING, (byte) 0);
  }

  @Override
  public void method_5773() {
    super.method_5773();
    if (!this.method_73183().method_8608()) {
      this.setClimbingWall(this.field_5976);
    }
    if (this.method_5618() >= 0 && this.method_5765()) {
      this.method_29239();
    }
  }

  @Override
  public boolean method_6474(class_1429 other) {
    if (this.method_5782() || other.method_5782()) {
      return false;
    }
    return super.method_6474(other);
  }

  @Override
  public void method_49794(class_3218 world, class_1429 other, @Nullable class_1296 baby) {
    super.method_49794(world, other, baby);
    if (baby != null) {
      baby.method_5873(this, true, true);
    }
  }

  public void setClimbingWall(boolean climbing) {
    byte b = this.field_6011.method_12789(CLIMBING);
    if (climbing) {
      b = (byte) (b | 1);
    } else {
      b = (byte) (b & -2);
    }

    this.field_6011.method_12778(CLIMBING, b);
  }

  @Override
  public boolean method_5974(double d) {
    return !this.method_16914() && !this.method_5782();
  }

  @Override
  public void method_6480(@Nullable class_1657 player) {
    this.method_5971();
    super.method_6480(player);
  }

  class MateGoal extends class_1341 {

    public MateGoal(class_1429 crab) {
      super(crab, 1.0F);
    }

    @Override
    public boolean method_6264() {
      if (this.field_6404.method_5782()) {
        return false;
      }
      return super.method_6264();
    }

    @Override
    public boolean method_6266() {
      if (!this.field_6406.method_5782()) {
        return false;
      }
      return super.method_6266();
    }

    @Override
    public void method_6268() {
      super.method_6268();
      if (this.field_6404.method_5858(this.field_6406) < 9.0) {  // kludge to fix failure to breed
        this.method_6249();
      }
    }
  }
}
